# Changelog

## [0.1.2] - 2025-11-14

### Changed

- Add form to `table_row` provider

### Fixed

- Ensure a season lasts less than 9 months

## [0.1.1] - 2025-04-04

### Fixed

- Ensure league generates players with reasonable DOBs


## [0.1.0] - 2025-04-03

_Initial release._

[0.1.2]: https://github.com/fourtreestech/ilc-provider/releases/tag/v0.1.2

[0.1.1]: https://github.com/fourtreestech/ilc-provider/releases/tag/v0.1.1

[0.1.0]: https://github.com/fourtreestech/ilc-provider/releases/tag/v0.1.0
